@@ -1,10 +1,4 @@
-import os
 from libs3tl import Step
-import json
-import pandas as pd
-
-
-
 
 class Ml(Step.Step):
     def __init__(self):
@@ -12,7 +6,7 @@ class Ml(Step.Step):
         self.step = "Ml"
         self.paramsFile = 'ML.properties'
         self.logger = 'logMl'
-        self.logFile = self.getRelativeFile(os.getcwd() +'\../logs/Ml.log')
+        self.logFile = self.getRelativeFile('../logs/Ml.log')
 
     def startup(self):
         super(Ml,self).startup()
@@ -32,7 +26,3 @@ class Ml(Step.Step):
 
     def getpicklename(self):
         pass
-
- 
-
-
