@@ -1,9 +1,5 @@
-import inspect
-import json
-import os
-import time
 from libs3tl import Step
-import pandas as pd
+
 
 class Transform(Step.Step):
     def __init__(self):
@@ -11,8 +7,7 @@ class Transform(Step.Step):
         self.step = "Tr"
         self.paramsFile = 'Transform.properties'
         self.logger = 'logTransform'
-        self.logFile = self.getRelativeFile(os.getcwd() + '\../logs/Transform.log')
-
+        self.logFile = self.getRelativeFile('../logs/Transform.log')
 
     def startup(self):
         super(Transform,self).startup()
